@@ -47,7 +47,6 @@
  */
 
 
-#define  NEEDSDIR               /* for stat() */
 #include "copyright.h"
 #include "xv.h"
 
@@ -56,7 +55,6 @@
 #include "bits/copy"
 #include "bits/copym"
 
-#define DBLCLKTIME 500
 #define CLIPPROP   "XV_CLIPBOARD"
 
 
@@ -102,7 +100,7 @@ static Cursor cutcurs  = (Cursor) 0;
 
 
 /********************************************/
-int CutAllowed()
+int CutAllowed(void)
 {
   /* returns '1' if cut/copy/clear commands should be enabled (ie, if
      there's a selection of some sort */
@@ -112,7 +110,7 @@ int CutAllowed()
 
 
 /********************************************/
-int PasteAllowed()
+int PasteAllowed(void)
 {
   Atom        clipAtom;
   struct stat st;
@@ -138,7 +136,7 @@ int PasteAllowed()
 
 
 /********************************************/
-void DoImgCopy()
+void DoImgCopy(void)
 {
   /*
    * called when 'Copy' command is issued.  does entire user interface,
@@ -162,7 +160,7 @@ void DoImgCopy()
 
 
 /********************************************/
-void DoImgCut()
+void DoImgCut(void)
 {
   /*
    * called when 'Cut' command is issued.  does entire user interface,
@@ -188,7 +186,7 @@ void DoImgCut()
 
 
 /********************************************/
-void DoImgClear()
+void DoImgClear(void)
 {
   /* called when 'Clear' command is issued */
 
@@ -201,7 +199,7 @@ void DoImgClear()
 
 
 /********************************************/
-void DoImgPaste()
+void DoImgPaste(void)
 {
   byte *cimg;
 
@@ -212,7 +210,7 @@ void DoImgPaste()
 
   /* if there's no selection, make one! */
   if (!HaveSelection()) makePasteSel(cimg);
-                   else doPaste(cimg);
+  doPaste(cimg);
 
   free(cimg);
   SetCursors(-1);
@@ -220,8 +218,7 @@ void DoImgPaste()
 
 
 /********************************************/
-static void doPaste(cimg)
-     byte *cimg;
+static void doPaste(byte *cimg)
 {
   /*
    * This is fairly hairy.
@@ -571,7 +568,7 @@ static void doPaste(cimg)
 
 
 /********************************************/
-static void buildCursors()
+static void buildCursors(void)
 {
   Pixmap p1,p2,p3,p4;
   XColor cfg, cbg;
@@ -604,7 +601,7 @@ static void buildCursors()
 
 
 /********************************************/
-static byte *getSelection()
+static byte *getSelection(void)
 {
   /* alloc's and builds image with values based on currently selected
    * portion of the image.  Returns NULL on failure
@@ -726,7 +723,7 @@ static byte *getSelection()
 
 
 /********************************************/
-static byte *getFromClip()
+static byte *getFromClip(void)
 {
   /* gets whatever data is on the clipboard, in CIMG_* format */
 
@@ -852,8 +849,7 @@ static byte *getFromClip()
 
 
 /********************************************/
-void SaveToClip(cimg)
-     byte *cimg;
+void SaveToClip(byte *cimg)
 {
   /* takes the 'thing' pointed to by data and sticks it on the clipboard.
      always tries to use the property method.  If it gets a BadAlloc
@@ -924,7 +920,7 @@ void SaveToClip(cimg)
 
 
 /********************************************/
-static void clearSelectedArea()
+static void clearSelectedArea(void)
 {
   /* called by 'Cut' or 'Clear' functions.  fills the selected area of the
      image with either clearR,clearG,clearB (in PIC24 mode), or editColor
@@ -962,7 +958,7 @@ static void clearSelectedArea()
 
 
 /********************************************/
-static void makeClipFName()
+static void makeClipFName(void)
 {
   const char *homedir;
 
@@ -984,9 +980,7 @@ static void makeClipFName()
 
 
 /********************************************/
-static int countcols24(pic, pwide, phigh, x, y, w, h)
-     byte *pic;
-     int   pwide, phigh, x,y,w,h;
+static int countcols24(byte *pic, int pwide, int phigh, int x, int y, int w, int h)
 {
   /* counts the # of unique colors in a selected rect of a 24-bit image
      returns '0-256' or >256 */
@@ -995,6 +989,8 @@ static int countcols24(pic, pwide, phigh, x, y, w, h)
   u_int rgb[257], col;
   byte *pp;
 
+  XV_UNUSED(phigh);
+
   nc = 0;
 
   for (i=y; nc<257 && i<y+h; i++) {
@@ -1012,9 +1008,7 @@ static int countcols24(pic, pwide, phigh, x, y, w, h)
 
 
 /********************************************/
-static int countNewCols(newpic, w,h, newcmap, is24, cx,cy,cw,ch)
-     byte *newpic, *newcmap;
-     int   w,h, is24, cx,cy,cw,ch;
+static int countNewCols(byte *newpic, int w, int h, byte *newcmap, int is24, int cx, int cy, int cw, int ch)
 {
   /* computes the number of NEW colors in the specified region of the
    * new pic, with respect to 'pic'.  returns 0-257 (where 257 means
@@ -1027,6 +1021,8 @@ static int countNewCols(newpic, w,h, newcmap, is24, cx,cy,cw,ch)
 
   if (picType != PIC8) return 0;           /* shouldn't happen */
 
+  XV_UNUSED(h);
+
   nc = 0;    /* # of new colors */
 
   if (is24) {
@@ -1081,8 +1077,7 @@ static int countNewCols(newpic, w,h, newcmap, is24, cx,cy,cw,ch)
 
 
 /********************************************/
-void CropRect2Rect(xp,yp,wp,hp, cx,cy,cw,ch)
-    int *xp, *yp, *wp, *hp, cx, cy, cw, ch;
+void CropRect2Rect(int *xp, int *yp, int *wp, int *hp, int cx, int cy, int cw, int ch)
 {
   /* crops rect xp,yp,wp,hp to be entirely within bounds of cx,cy,cw,ch */
 
@@ -1109,7 +1104,7 @@ void CropRect2Rect(xp,yp,wp,hp, cx,cy,cw,ch)
 
 
 /********************************************/
-void InitSelection()
+void InitSelection(void)
 {
   selrx = selry = selrw = selrh = 0;
   haveSel     = 0;
@@ -1121,22 +1116,21 @@ void InitSelection()
 
 
 /********************************************/
-int HaveSelection()
+int HaveSelection(void)
 {
   return haveSel;
 }
 
 
 /********************************************/
-int GetSelType()
+int GetSelType(void)
 {
   return selType;
 }
 
 
 /********************************************/
-void GetSelRCoords(xp, yp, wp, hp)
-     int *xp, *yp, *wp, *hp;
+void GetSelRCoords(int *xp, int *yp, int *wp, int *hp)
 {
   /* returns selection rectangle x,y,w,h in pic coordinates */
 
@@ -1149,8 +1143,7 @@ void GetSelRCoords(xp, yp, wp, hp)
 
 
 /********************************************/
-void EnableSelection(enab)
-     int enab;
+void EnableSelection(int enab)
 {
   haveSel = enab;
   BTSetActive(&but[BCROP], enab);
@@ -1166,8 +1159,7 @@ void EnableSelection(enab)
 
 
 /***********************************/
-int DoSelection(ev)
-     XButtonEvent *ev;
+int DoSelection(XButtonEvent *ev)
 {
   int          px, py, rv;
   static Time  lastClickTime   = 0;
@@ -1197,7 +1189,7 @@ int DoSelection(ev)
 
   if (ev->button == Button1) {
     /* double clicked B1 ? */
-    if (lastClickButton==Button1 && (ev->time - lastClickTime) < DBLCLKTIME) {
+    if (lastClickButton==Button1 && (ev->time - lastClickTime) < DBLCLICKTIME) {
       lastClickButton=Button3;
       if (HaveSelection() && PTINRECT(px, py, selrx, selry, selrw, selrh)) {
 	EnableSelection(0);
@@ -1244,8 +1236,7 @@ int DoSelection(ev)
 
 
 /********************************************/
-static int dragHandle(ev)
-     XButtonEvent *ev;
+static int dragHandle(XButtonEvent *ev)
 {
   /* called on a B1 press inside the selection area.  if mouse clicked on
    * one of the selection handles, drag the handle until released.
@@ -1358,10 +1349,8 @@ static int dragHandle(ev)
 	             else { chwide=1;  newwide = seh; }
       }
       else {         /* constrain to same aspect ratio */
-	double asp;
 	if (seh==0) { chwide=1; newwide=0; }
 	else {
-	  asp = (double) sew / (double) seh;
 	  if (islf || isrt) { chhigh=1;  newhigh = (int) (sew/orgaspect); }
                        else { chwide=1;  newwide = (int) (seh*orgaspect); }
 	}
@@ -1410,10 +1399,7 @@ static int dragHandle(ev)
 
 
 /********************************************/
-static void dragSelection(ev, bmask, dragndrop)
-     XButtonEvent *ev;
-     unsigned int bmask;
-     int          dragndrop;
+static void dragSelection(XButtonEvent *ev, unsigned int bmask, int dragndrop)
 {
   /* called on a button press inside the selection area.  drags selection
    * around until button has been released.  Selection may be dragged outside
@@ -1524,8 +1510,7 @@ static void dragSelection(ev, bmask, dragndrop)
 
 
 /***********************************/
-static void rectSelection(ev)
-     XButtonEvent *ev;
+static void rectSelection(XButtonEvent *ev)
 {
   Window       rW,cW;
   int          rx,ry,ox,oy,x,y,active, x1, y1, x2, y2, cnstrain;
@@ -1607,8 +1592,7 @@ static void rectSelection(ev)
 
 
 /***********************************/
-void DrawSelection(newcol)
-     int newcol;
+void DrawSelection(int newcol)
 {
   /* doesn't affect 'haveSel', as when moving/resizing/tracking the
      selection we need to erase it and redraw it.  If 'chcol' is
@@ -1700,8 +1684,7 @@ void DrawSelection(newcol)
 
 
 /********************************************/
-void MoveGrowSelection(dx,dy,dw,dh)
-     int dx,dy,dw,dh;
+void MoveGrowSelection(int dx, int dy, int dw, int dh)
 {
   /* moves and/or grows the selection by the specified amount
      (in pic coords).  keeps the selection entirely within 'pic'.
@@ -1731,8 +1714,7 @@ void MoveGrowSelection(dx,dy,dw,dh)
 
 
 /***********************************/
-void BlinkSelection(cnt)
-     int cnt;
+void BlinkSelection(int cnt)
 {
   if (!HaveSelection()) return;
 
@@ -1745,8 +1727,7 @@ void BlinkSelection(cnt)
 
 
 /***********************************/
-void FlashSelection(cnt)
-     int cnt;
+void FlashSelection(int cnt)
 {
   int i;
 
@@ -1765,8 +1746,7 @@ void FlashSelection(cnt)
 
 
 /********************************************/
-static void makePasteSel(cimg)
-     byte *cimg;
+static void makePasteSel(byte *cimg)
 {
   /* makes a selection rectangle the size of the beastie on the clipboard,
    * centered on cpic.  selection is allowed to be bigger than pic
@@ -1795,8 +1775,7 @@ static void makePasteSel(cimg)
 /********************************************/
 
 
-void CoordE2C(ex, ey, cx_ret, cy_ret)
-     int ex, ey, *cx_ret, *cy_ret;
+void CoordE2C(int ex, int ey, int *cx_ret, int *cy_ret)
 {
   /* the weirdness causes everything to round towards neg infinity */
   *cx_ret = ((ex*cWIDE) / eWIDE) + ((ex<0) ? -1 : 0);
@@ -1804,8 +1783,7 @@ void CoordE2C(ex, ey, cx_ret, cy_ret)
 }
 
 
-void CoordC2E(cx, cy, ex_ret, ey_ret)
-     int cx, cy, *ex_ret, *ey_ret;
+void CoordC2E(int cx, int cy, int *ex_ret, int *ey_ret)
 {
   /* this makes positive #s round to +inf, and neg # round to -inf */
   if (cx>=0) *ex_ret = (cx*eWIDE + (cWIDE-1)) / cWIDE;
@@ -1815,24 +1793,21 @@ void CoordC2E(cx, cy, ex_ret, ey_ret)
 }
 
 
-void CoordP2C(px, py, cx_ret, cy_ret)
-     int px, py, *cx_ret, *cy_ret;
+void CoordP2C(int px, int py, int *cx_ret, int *cy_ret)
 {
   *cx_ret = px - cXOFF;
   *cy_ret = py - cYOFF;
 }
 
 
-void CoordC2P(cx, cy, px_ret, py_ret)
-     int cx, cy, *px_ret, *py_ret;
+void CoordC2P(int cx, int cy, int *px_ret, int *py_ret)
 {
   *px_ret = cx + cXOFF;
   *py_ret = cy + cYOFF;
 }
 
 
-void CoordP2E(px, py, ex_ret, ey_ret)
-     int px, py, *ex_ret, *ey_ret;
+void CoordP2E(int px, int py, int *ex_ret, int *ey_ret)
 {
   int cx, cy;
   CoordP2C(px, py, &cx, &cy);
@@ -1840,8 +1815,7 @@ void CoordP2E(px, py, ex_ret, ey_ret)
 }
 
 
-void CoordE2P(ex, ey, px_ret, py_ret)
-     int ex, ey, *px_ret, *py_ret;
+void CoordE2P(int ex, int ey, int *px_ret, int *py_ret)
 {
   int cx, cy;
   CoordE2C(ex, ey, &cx, &cy);
@@ -1849,8 +1823,7 @@ void CoordE2P(ex, ey, px_ret, py_ret)
 }
 
 
-static void CoordE2Prnd(ex, ey, px_ret, py_ret)
-     int ex, ey, *px_ret, *py_ret;
+static void CoordE2Prnd(int ex, int ey, int *px_ret, int *py_ret)
 {
   int cx, cy;
   cx = ((ex*cWIDE + (eWIDE/2)) / eWIDE) + ((ex<0) ? -1 : 0);
@@ -1860,8 +1833,7 @@ static void CoordE2Prnd(ex, ey, px_ret, py_ret)
 }
 
 
-void MaskSelect (x1,x2,y1,y2)
-int x1,x2,y1,y2;
+void MaskSelect (int x1, int x2, int y1, int y2)
 {
 	selrx = x1;  selry = y1;  selrw = x2;  selrh = y2;
 	EnableSelection(1);
