@@ -60,7 +60,6 @@
  *  同様に書き込み時にも問題が生じるかもしれない。
  */
 
-#define  NEEDSDIR               /* for stat() */
 #include "xv.h"
 
 
@@ -1755,7 +1754,7 @@ void CreateMGCSFXW()
 
 
   mgcsfxW = CreateWindow("xv mgcsfx", "XVmgcsfx", NULL,
-			 MSWIDE, MSHIGH, infofg, infobg, 0);
+			 MSWIDE, MSHIGH, infofg, infobg, FALSE);
   if (!mgcsfxW) FatalError("can't create mgcsfx window!");
 
   XSelectInput(theDisp, mgcsfxW,
